==> zscaler_sdk_python-1.3.0.tar.gz: zscaler_sdk_python-1.3.0/zscaler/zpa/models/application_servers.py <==
"""
Copyright (c) 2023, Zscaler Inc.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted, provided that the above
copyright notice and this permission notice appear in all copies.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
"""

from zscaler.oneapi_object import ZscalerObject


class AppServers(ZscalerObject):
    """
    A class for Application Server objects.
    """

    def __init__(self, config=None):
        super().__init__(config)
        if config:
            self.id = config["id"] if "id" in config else None
            self.name = config["name"] if "name" in config else None
            self.address = config["address"] if "address" in config else None

            # Using .get() with default values for booleans and lists
            self.enabled = config.get("enabled", True)
            self.description = config["description"] if "description" in config else None
            self.app_server_group_ids = config["appServerGroupIds"] if "appServerGroupIds" in config else []
            self.config_space = config["configSpace"] if "configSpace" in config else "DEFAULT"
        else:
            # Default values when no config is provided
            self.id = None
            self.name = None
            self.address = None
            self.enabled = True
            self.description = None
            self.app_server_group_ids = []
            self.config_space = "DEFAULT"

    def request_format(self):
        """
        Return a dictionary representing this object for API requests.
        """
        parent_req_format = super().request_format()
        current_obj_format = {
            "id": self.id,
            "name": self.name,
            "address": self.address,
            "enabled": self.enabled,
            "description": self.description,
            "appServerGroupIds": self.app_server_group_ids,
            "configSpace": self.config_space,
        }
        parent_req_format.update(current_obj_format)
        return parent_req_format

==> zscaler_sdk_python-1.9.2.tar.gz: zscaler_sdk_python-1.9.2/zscaler/zpa/models/application_servers.py <==
"""
Copyright (c) 2023, Zscaler Inc.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted, provided that the above
copyright notice and this permission notice appear in all copies.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
"""

from typing import Dict, List, Optional, Any, Union
from zscaler.oneapi_object import ZscalerObject


class AppServers(ZscalerObject):
    """
    A class for Application Server objects.
    """

    def __init__(self, config: Optional[Dict[str, Any]] = None) -> None:
        super().__init__(config)
        if config:
            self.id = config["id"] if "id" in config else None
            self.name = config["name"] if "name" in config else None
            self.address = config["address"] if "address" in config else None

            # Using .get() with default values for booleans and lists
            self.enabled = config.get("enabled", True)
            self.description = config["description"] if "description" in config else None
            self.app_server_group_ids = config["appServerGroupIds"] if "appServerGroupIds" in config else []
            self.config_space = config["configSpace"] if "configSpace" in config else "DEFAULT"
        else:
            # Default values when no config is provided
            self.id = None
            self.name = None
            self.address = None
            self.enabled = True
            self.description = None
            self.app_server_group_ids = []
            self.config_space = "DEFAULT"

    def request_format(self) -> Dict[str, Any]:
        """
        Return a dictionary representing this object for API requests.
        """
        parent_req_format = super().request_format()
        current_obj_format = {
            "id": self.id,
            "name": self.name,
            "address": self.address,
            "enabled": self.enabled,
            "description": self.description,
            "appServerGroupIds": self.app_server_group_ids,
            "configSpace": self.config_space,
        }
        parent_req_format.update(current_obj_format)
        return parent_req_format
